pub enum KeyError {
InvalidPublicKey,
InvalidPrivateKey,
}Expand description
Why constructing a local key failed.
Variants
InvalidPublicKey
The bytes are not a valid public key for the key type.
InvalidPrivateKey
The bytes are not a valid private key (scalar) for the key type.